@@ -21,9 +21,9 @@
 
 const VERSION = require('../package.json').version;
 
-const fs = require('fs-extra');
-const path = require('path');
-const unorm = require('unorm');
+const fs = require('node:fs');
+const path = require('node:path');
+const util = require('node:util');
 const projectFile = require('./projectFile');
 const check_reqs = require('./check_reqs');
 const {
@@ -33,7 +33,6 @@ const {
     events,
     PluginManager
 } = require('cordova-common');
-const util = require('util');
 
 function setupEvents (externalEventEmitter) {
     if (externalEventEmitter) {
@@ -111,7 +110,7 @@ class Api {
             www: path.join(this.root, 'www'),
             platformWww: path.join(this.root, 'platform_www'),
             configXml: path.join(xcodeCordovaProj, 'config.xml'),
-            defaultConfigXml: path.join(this.root, 'cordova/defaults.xml'),
+            defaultConfigXml: path.join(this.root, 'cordova', 'defaults.xml'),
             pbxproj: path.join(this.root, xcodeProjDir, 'project.pbxproj'),
             xcodeProjDir: path.join(this.root, xcodeProjDir),
             xcodeCordovaProj
@@ -142,7 +141,7 @@ class Api {
         // CB-6992 it is necessary to normalize characters
         // because node and shell scripts handles unicode symbols differently
         // We need to normalize the name to NFD form since iOS uses NFD unicode form
-        const name = unorm.nfd(config.name());
+        const name = config.name().normalize('NFD');
         let result;
         try {
             result = require('./create')
