@@ -17,13 +17,14 @@
  * under the License.
  */
 
-const path = require('path');
+const fs = require('node:fs');
+const fsp = require('node:fs/promises');
+const path = require('node:path');
+const util = require('node:util');
 const which = require('which');
 const execa = require('execa');
 const { CordovaError, events } = require('cordova-common');
-const fs = require('fs-extra');
 const plist = require('plist');
-const util = require('util');
 
 const check_reqs = require('./check_reqs');
 const projectFile = require('./projectFile');
@@ -177,10 +178,10 @@ module.exports.run = function (buildOpts) {
             }
             if (buildOpts.provisioningProfile) {
                 if (typeof buildOpts.provisioningProfile === 'string') {
-                    extraConfig += `PROVISIONING_PROFILE = ${buildOpts.provisioningProfile}\n`;
+                    extraConfig += `PROVISIONING_PROFILE_SPECIFIER = ${buildOpts.provisioningProfile}\n`;
                 } else {
                     const keys = Object.keys(buildOpts.provisioningProfile);
-                    extraConfig += `PROVISIONING_PROFILE = ${buildOpts.provisioningProfile[keys[0]]}\n`;
+                    extraConfig += `PROVISIONING_PROFILE_SPECIFIER = ${buildOpts.provisioningProfile[keys[0]]}\n`;
                 }
             }
             if (buildOpts.developmentTeam) {
@@ -206,7 +207,7 @@ module.exports.run = function (buildOpts) {
                 writeCodeSignStyle('Automatic');
             }
 
-            return fs.writeFile(path.join(projectPath, 'cordova/build-extras.xcconfig'), extraConfig, 'utf-8');
+            return fsp.writeFile(path.join(projectPath, 'cordova', 'build-extras.xcconfig'), extraConfig, 'utf-8');
         }).then(() => {
             const configuration = buildOpts.release ? 'Release' : 'Debug';
 
@@ -218,7 +219,7 @@ module.exports.run = function (buildOpts) {
             const buildOutputDir = path.join(projectPath, 'build', `${configuration}-${(buildOpts.device ? 'iphoneos' : 'iphonesimulator')}`);
 
             // remove the build output folder before building
-            fs.removeSync(buildOutputDir);
+            fs.rmSync(buildOutputDir, { recursive: true, force: true });
 
             const xcodebuildArgs = getXcodeBuildArgs(projectName, projectPath, configuration, emulatorTarget, buildOpts);
             return execa('xcodebuild', xcodebuildArgs, { cwd: projectPath, stdio: 'inherit' });
@@ -278,7 +279,7 @@ module.exports.run = function (buildOpts) {
                 return execa('xcodebuild', xcodearchiveArgs, { cwd: projectPath, stdio: 'inherit' });
             }
 
-            return fs.writeFile(exportOptionsPath, exportOptionsPlist, 'utf-8')
+            return fsp.writeFile(exportOptionsPath, exportOptionsPlist, 'utf-8')
                 .then(checkSystemRuby)
                 .then(packageArchive);
         })
